Crate wsz

Crate wsz 

wsz is a Rust library for unpacking Winamp skins into sprites. It can also pack the sprites back into a .wsz file and generate a screenshot of the skin as it would appear in Winamp.

A guide to the format can be found at https://winampskins.neocities.org/

Most of this code heavily inspired by https://github.com/captbaritone/webamp

Modules

archive
Logic for unpacking and packing Winamp skins from archive (zip) format
error
Error types for the wsz library
sprites
Sprite definitions for Winamp skin elements
text
Support for the various text files in Winamp skins

Structs

Wsz
Top-level container for a Winamp skin. Start here.